@@ -45,16 +45,15 @@ function(x, fact=2, fun=mean, expand=TRUE, na.rm=TRUE, filename="", old=FALSE, .
 	extent(outRaster) <- bndbox
 	rowcol(outRaster) <- c(rsteps, csteps) 
 
-	if (class(fun) == 'character') {
-		if (! fun %in% c('sum', 'mean') ) {
-			stop("If 'fun' is a character variable, it should be either 'sum' or 'mean'")
-		}
-	}
-	
-	if (! fromDisk(x) & ! inMemory(x)) {
-		return(outRaster)
-	}	
+	if (! hasValues(x) ) {	return(outRaster) }	
 
+	fun <- .makeTextFun(fun)
+	if (class(fun) == 'character') { 
+		rowcalc <- TRUE 
+		fun <- .getRowFun(fun)
+	} else { rowcalc <- FALSE }
+	
+	
 	if (!expand) {
 		lastcol <- csteps * yfact
 		lastrow <- rsteps * xfact
@@ -100,12 +99,8 @@ function(x, fact=2, fun=mean, expand=TRUE, na.rm=TRUE, filename="", old=FALSE, .
 				vv[1:length(vals)] = vals
 			}
 			
-			if (is.character(fun)) {
-				if (fun == 'mean') {
-					vals <- colMeans(vv, na.rm=na.rm )
-				} else {
-					vals <- colSums(vv, na.rm=na.rm )			
-				}
+			if (rowcalc) {
+				vals <- fun(t(vv), na.rm=na.rm )
 			} else {
 				vals <- apply(vv, 2, fun, na.rm=na.rm )
 			}
