@@ -6,8 +6,10 @@
 
 setMethod("[[", c("RasterStackBrick","ANY", "ANY"),
 function(x,i,j,...,drop=TRUE) {
-	if (!missing(i) && class(i) == "RasterLayer") {
-		i <- as.logical( getValues(i) ) 
+	if (!missing(i)) {
+		if ( inherits(i, "RasterLayer")) {
+			i <- as.logical( getValues(i) ) 
+		}
 	}
 	if ( missing(j) ) {
 		cells <- cellFromRow(x, i)
